<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicație Proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tip proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresa IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opțional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Verificați „Utilizați un proxy” în meniul contextual al aplicației din Launcher după configurare</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvare</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresă IP invalidă</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Port invalid</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Deconectare</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Ștergeți</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvare</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Deconectare</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Sigur doriţi să ştergeţi această configuraţie?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexiune prin cablu %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexiune PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPN nou</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tip VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Export</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Reţea</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicație Proxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot Personal</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detaliile rețelei</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy sistem</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rețea conectată</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rețea fără fir</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptor de rețea cablu</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Adaugare conexiune rețea</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptor Rețea Wireless</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectare la rețele ascunse</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Creează o conexiune PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Stare VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Creează VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importă VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tip proxy</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configurare</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresa IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Creează Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfață</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandă</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primar</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mască de rețea</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Viteză</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Adresă DNS invalidă</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Reţea Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nelegat</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresa MAC a dispozitivului</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Adresa MAC clonată a dispozitivului</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizare MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Numele există deja</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Conectare Automată</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Adăugare Setări</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Creează Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Adresa IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresă IP invalidă</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmask invalid</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mască de rețea</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresă IP invalidă</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorare</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresa IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Aplicat doar în resursele corespunzătoare</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Modalitate</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mască de rețea</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresă IP invalidă</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmask invalid</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Reţea</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Modalitate</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorare</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detaliile rețelei</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy sistem</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicație Proxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detaliile rețelei</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Reţea</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dezactivat</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configurează după Manager Reţea</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot Personal</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Serviciu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuzare autentificare EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuzare autentificare PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuzare autentificare CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuzare autentificare MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuzare autentificare MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nu există comprimare a datelor BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Comprimare a datelor fără diminuarea acestora</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nu există comprimare a titlului TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nu există comprimare pentru câmpul protocolar</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nu există comprimare pentru adresă/control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Trimite pachete ecou PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utilizare MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE  128 octeţi</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE complet etapizat</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Creează o conexiune PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy sistem</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvare</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tip proxy</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opțional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignoră configurațiile proxy pentru gazdele și domeniile de mai sus</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configurare</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Securizare</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS tunelizat</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP Protejat</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Salvați parola pentru acest utilizator</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Salvați parola pentru toți utilizatorii</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Întreabă mereu</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dezactivat</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonim</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autentificat</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambele</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automat</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versiune 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versiune 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autentificare EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitate</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opțiuni Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Cheie privată</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificatul utilizatorului</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Anonim</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provizionare</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Fişierul PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autentificare internă</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versiune PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Parolă privată</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Parolă Invalidă</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nici un</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Securizare</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Cheie</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Cerințele Securității</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Parolă Invalidă</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nici un</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Cheie partajată</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistem deschis</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Securizare</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentificare</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Cheie</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN avansat</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Particularizarea  portalului</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Portal</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Particularizarea intervalului de renegociere</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interval renegociere</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Utilizare Compresie Date LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Utilizare conexiune TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Utilizare dispozitiv Tactil</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Particularizarea tunel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalizarea dimensiunii fragmentului UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Dimensiune fragment UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restricționarea tunel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Selecție  aleatorie a host-urilor la distanță</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN avansat</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (implicit)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Securizat (implicit)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Slab</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nici un</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Cînd este disponibil (implicit)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Întotdeauna NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dezactivat</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupul 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupul 2 (implicit)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupul 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (implicit)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupul 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domeniu</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Furnizor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versiune</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Criptare</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Mod traversal NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grup IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Redirecționare cu caracter secret</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Dezactivare detectarea perechii inactive</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Activare IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nume Grup</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID Grup</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Cheie Pre-Shared</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmi Faza1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmi Faza2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permite troianul Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificatul utilizatorului</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Cheie privată</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Aplicaţi FSID pentru fraza -cheie</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificate (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificatele cu Parola (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Cheie tip Static</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvat</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Întreabă</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nu este necesar</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipul Autentificării</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificatul utilizatorului</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Cheie privată</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opțiuni Pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Parolă privată</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Setare Direcţie Cheie</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direcţie Cheie</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP îndepărtat</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP local</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Toate Disponibile (implicit)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 octeţi (mai puţin securizat)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 octeţi (cel mai securizat)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuzare autentificare EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuzare autentificare PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuzare autentificare CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuzare autentificare MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuzare autentificare MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nu există comprimare a datelor BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Comprimare a datelor fără diminuarea acestora</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nu există comprimare a titlului TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nu există comprimare pentru câmpul protocolar</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nu există comprimare pentru adresă/control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Trimite pachete ecou PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utilizare MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Securizare</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE complet etapizat</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Stare VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Creează VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importă VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Eroare la importare</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Eroare fișier</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nu este necesar</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tip proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP server</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>În caz de eşec încercați din nou</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Fişierul CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignoră Avertismente Certificat</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Utilizare extensii nume gazdă TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Securitate VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Implicit</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nici un</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cifra</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autentificare HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvat</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Întreabă</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nu este necesar</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opțiuni Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domeniu NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP server</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Cheie privată</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agent SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart Card</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Cheie Pre-Shared</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipul Autentificării</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificatul utilizatorului</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Solicitați o adresă IP interioară</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Impune încapsularea UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Utilizare Compresie IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Activați propunerile de cifrare personalizate</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autentificare TLS VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Implicit</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Potrivire subiect</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipul  certificatului la distanță</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Fişier cheie</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Setare Direcţie Cheie</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direcţie Cheie</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway invalid</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvat</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Întreabă</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nu este necesar</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Necesar</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume utilizator</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opțiuni Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nume Grup</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Parola Grup</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Utilizarea Autentificării Hibride</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Fişierul CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Conectați mai întâi cablul de rețea</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptor de rețea cablu</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Adaugare conexiune rețea</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Selectați Setări</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptor Rețea Wireless</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Închidere Hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Dezactivați întâi hotspot-ul dacă doriți să vă conectați la o rețea wireless</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectare la rețele ascunse</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nelegat</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresa MAC a dispozitivului</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizare MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tip Securitate</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandă</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfață</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mască de rețea</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primar</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Viteză</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispozitiv Dezactivat</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectat dar fară acces Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neconectat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cablu Reţea Deconectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificare</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obţinere Adresă IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectat</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Deconectat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Eșuat</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rețea conectată</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rețea Cablu %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rețea fără fir</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rețea fără fir %1</translation>
    </message>
</context>
</TS>